@@ -14,7 +14,7 @@ Usage::
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from datetime import datetime
 import sys
-from typing import Any, Dict, List, TYPE_CHECKING, overload
+from typing import Any, Dict, List, TYPE_CHECKING, Type, overload
 from botocore.exceptions import ClientError as Boto3ClientError
 from mypy_boto3_cloudwatch.paginator import (
     DescribeAlarmHistoryPaginator,
@@ -60,20 +60,20 @@ __all__ = ("CloudWatchClient",)
 
 
 class Exceptions:
-    ClientError: Boto3ClientError
-    ConcurrentModificationException: Boto3ClientError
-    DashboardInvalidInputError: Boto3ClientError
-    DashboardNotFoundError: Boto3ClientError
-    InternalServiceFault: Boto3ClientError
-    InvalidFormatFault: Boto3ClientError
-    InvalidNextToken: Boto3ClientError
-    InvalidParameterCombinationException: Boto3ClientError
-    InvalidParameterValueException: Boto3ClientError
-    LimitExceededException: Boto3ClientError
-    LimitExceededFault: Boto3ClientError
-    MissingRequiredParameterException: Boto3ClientError
-    ResourceNotFound: Boto3ClientError
-    ResourceNotFoundException: Boto3ClientError
+    ClientError: Type[Boto3ClientError]
+    ConcurrentModificationException: Type[Boto3ClientError]
+    DashboardInvalidInputError: Type[Boto3ClientError]
+    DashboardNotFoundError: Type[Boto3ClientError]
+    InternalServiceFault: Type[Boto3ClientError]
+    InvalidFormatFault: Type[Boto3ClientError]
+    InvalidNextToken: Type[Boto3ClientError]
+    InvalidParameterCombinationException: Type[Boto3ClientError]
+    InvalidParameterValueException: Type[Boto3ClientError]
+    LimitExceededException: Type[Boto3ClientError]
+    LimitExceededFault: Type[Boto3ClientError]
+    MissingRequiredParameterException: Type[Boto3ClientError]
+    ResourceNotFound: Type[Boto3ClientError]
+    ResourceNotFoundException: Type[Boto3ClientError]
 
 
 class CloudWatchClient:
