@@ -16,7 +16,7 @@ Usage::
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from datetime import datetime
 import sys
-from typing import Any, Iterator, List, TYPE_CHECKING, TypeVar
+from typing import Any, Generator, Iterator, List, TYPE_CHECKING, TypeVar
 from boto3.resources.base import ServiceResource as Boto3ServiceResource
 from boto3.resources.collection import ResourceCollection
 from mypy_boto3_cloudwatch.type_defs import (
@@ -82,7 +82,7 @@ class ServiceResourceAlarmsCollection(ResourceCollection):
     def page_size(self, count: int) -> "ServiceResourceAlarmsCollection":
         pass
 
-    def pages(self) -> Iterator["Alarm"]:
+    def pages(self) -> Generator[List["Alarm"], None, None]:
         pass
 
     def __iter__(self) -> Iterator["Alarm"]:
@@ -112,7 +112,7 @@ class ServiceResourceMetricsCollection(ResourceCollection):
     def page_size(self, count: int) -> "ServiceResourceMetricsCollection":
         pass
 
-    def pages(self) -> Iterator["Metric"]:
+    def pages(self) -> Generator[List["Metric"], None, None]:
         pass
 
     def __iter__(self) -> Iterator["Metric"]:
@@ -180,7 +180,7 @@ class MetricAlarmsCollection(ResourceCollection):
     def page_size(self, count: int) -> "MetricAlarmsCollection":
         pass
 
-    def pages(self) -> Iterator["Alarm"]:
+    def pages(self) -> Generator[List["Alarm"], None, None]:
         pass
 
     def __iter__(self) -> Iterator["Alarm"]:
